# Sublime Color Scheme Editor

Sublime Color Scheme Editor (subclrschm) is a graphical Sublime Text color scheme editor.  It is cross platform and runs in Windows, macOS, and Linux.

Windows

![Windows](./images/CSE_WIN.png)

macOS

![macOS](./images/CSE_OSX.png)

Linux

![Ubuntu](./images/CSE_NIX.png)
